@@ -5,7 +5,8 @@ implementations of it."""
 from ._tictactoe import TicTacToe
 from ._base import Base
 from ._connect_four import ConnectFour
+from ._factory import Factory
 from . import action_spaces
 
 
-__all__ = ["TicTacToe", "Base", "ConnectFour", "action_spaces"]
+__all__ = ["TicTacToe", "Base", "ConnectFour", "action_spaces", "Factory"]
